==> pgxRpi_1.0.3.tgz: pgxRpi/doc/Introduction_1_loadmetadata.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(pgxRpi)

## -----------------------------------------------------------------------------
# access all filters
all_filters <- pgxFilter()
# get all prefix
all_prefix <- pgxFilter(return_all_prefix = TRUE)
# access specific filters based on prefix
ncit_filters <- pgxFilter(prefix="NCIT")
head(ncit_filters)

## -----------------------------------------------------------------------------
biosamples <- pgxLoader(type="biosample", filters = "NCIT:C3512")
# data looks like this
biosamples[c(1700:1705),]

## -----------------------------------------------------------------------------
biosamples_2 <- pgxLoader(type="biosample", biosample_id = "pgxbs-kftvgioe",individual_id = "pgxind-kftx28q5")

metainfo <- c("biosample_id","individual_id","pubmed_id","histological_diagnosis_id","geoprov_city")
biosamples_2[metainfo]

## -----------------------------------------------------------------------------
biosamples_3 <- pgxLoader(type="biosample", filters = "NCIT:C3512",skip=0, limit = 1000)
# Dimension: Number of samples * features
print(dim(biosamples))
print(dim(biosamples_3))

## -----------------------------------------------------------------------------
pgxCount(filters = "NCIT:C3512")

## -----------------------------------------------------------------------------
unique(biosamples$histological_diagnosis_id)

## -----------------------------------------------------------------------------
biosamples_4 <- pgxLoader(type="biosample", filters = "NCIT:C3512",codematches = TRUE)

unique(biosamples_4$histological_diagnosis_id)

## -----------------------------------------------------------------------------
biosamples_5 <- pgxLoader(type="biosample", filters = c("NCIT:C3512","PMID:24174329"), 
                          filterLogic = "AND")

## -----------------------------------------------------------------------------
individuals <- pgxLoader(type="individual",filters="NCIT:C3270")
# Dimension: Number of individuals * features
print(dim(individuals))
# data looks like this
individuals[c(36:40),]

## -----------------------------------------------------------------------------
individual <- pgxLoader(type="individual",individual_id = "pgxind-kftx26ml", biosample_id="pgxbs-kftvh94d")

individual

## -----------------------------------------------------------------------------
# query metadata of individuals with lung adenocarcinoma
luad_inds <- pgxLoader(type="individual",filters="NCIT:C3512")
# use 65 years old as the splitting condition
pgxMetaplot(data=luad_inds, group_id="age_iso", condition="P65Y", pval=TRUE)

## ----echo = FALSE-------------------------------------------------------------
sessionInfo()

==> pgxRpi_1.1.7.tgz: pgxRpi/doc/Introduction_1_loadmetadata.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(pgxRpi)

## -----------------------------------------------------------------------------
# access all filters
all_filters <- pgxFilter()
head(all_filters)

## -----------------------------------------------------------------------------
# get all prefix
all_prefix <- pgxFilter(return_all_prefix = TRUE)
all_prefix

## -----------------------------------------------------------------------------
# access specific filters based on prefix
ncit_filters <- pgxFilter(prefix="NCIT")
head(ncit_filters)

## -----------------------------------------------------------------------------
biosamples <- pgxLoader(type="biosamples", filters = "NCIT:C7541")
# data looks like this
biosamples[1:5,]

## -----------------------------------------------------------------------------
biosamples_2 <- pgxLoader(type="biosamples", biosample_id = "pgxbs-kftvki7h",individual_id = "pgxind-kftx6ltu")

biosamples_2

## -----------------------------------------------------------------------------
biosamples_3 <- pgxLoader(type="biosamples", filters = "NCIT:C7541",skip=0, limit = 10)
# Dimension: Number of samples * features
print(dim(biosamples))
print(dim(biosamples_3))

## -----------------------------------------------------------------------------
unique(biosamples$histological_diagnosis_id)

## -----------------------------------------------------------------------------
biosamples_4 <- pgxLoader(type="biosamples", filters = "NCIT:C7541",codematches = TRUE)
unique(biosamples_4$histological_diagnosis_id)

## -----------------------------------------------------------------------------
pgxLoader(type="sample_count",filters = "NCIT:C7541")

## -----------------------------------------------------------------------------
individuals <- pgxLoader(type="individuals",individual_id = "pgxind-kftx26ml",filters="NCIT:C7541")
# data looks like this
individuals[173:174,]

## -----------------------------------------------------------------------------
analyses <- pgxLoader(type="analyses",biosample_id = c("pgxbs-kftvik5i","pgxbs-kftvik96"))

analyses

## -----------------------------------------------------------------------------
# query metadata of individuals with lung adenocarcinoma
luad_inds <- pgxLoader(type="individual",filters="NCIT:C3512")
# use 65 years old as the splitting condition
pgxMetaplot(data=luad_inds, group_id="age_iso", condition="P65Y", pval=TRUE)

## ----echo = FALSE-------------------------------------------------------------
sessionInfo()
